@@ -12,6 +12,7 @@ from edx_name_affirmation.models import VerifiedName
 from edx_name_affirmation.signals import VERIFIED_NAME_APPROVED
 from edx_name_affirmation.statuses import VerifiedNameStatus
 from edx_name_affirmation.tasks import idv_update_verified_name, proctoring_update_verified_name
+from edx_name_affirmation.toggles import is_verified_name_enabled
 
 User = get_user_model()
 
@@ -42,7 +43,8 @@ def idv_attempt_handler(attempt_id, user_id, status, photo_id_name, full_name, *
         photo_id_name(str): name to be used as verified name
         full_name(str): user's pending name change or current profile name
     """
-    idv_update_verified_name.delay(attempt_id, user_id, status, photo_id_name, full_name)
+    if is_verified_name_enabled():
+        idv_update_verified_name.delay(attempt_id, user_id, status, photo_id_name, full_name)
 
 
 def proctoring_attempt_handler(
@@ -69,13 +71,14 @@ def proctoring_attempt_handler(
         is_proctored(boolean): if the exam attempt is for a proctored exam
         backend_supports_onboarding(boolean): if the exam attempt is for an exam with a backend that supports onboarding
     """
-    proctoring_update_verified_name.delay(
-        attempt_id,
-        user_id,
-        status,
-        full_name,
-        profile_name,
-        is_practice_exam,
-        is_proctored,
-        backend_supports_onboarding
-    )
+    if is_verified_name_enabled():
+        proctoring_update_verified_name.delay(
+            attempt_id,
+            user_id,
+            status,
+            full_name,
+            profile_name,
+            is_practice_exam,
+            is_proctored,
+            backend_supports_onboarding
+        )
